@@ -1,5 +1,6 @@
 use super::*;
 
+use compt::Visitor;
 fn assert_length<I: core::iter::ExactSizeIterator>(it: I) {
     let len = it.size_hint().0;
     assert_eq!(it.count(), len);
@@ -16,7 +17,7 @@ fn test() {
 
     let mut tree = crate::new(&mut bots);
 
-    queries::assert_tree_invariants(&tree);
+    tree.assert_tree_invariants();
 
     assert_length(tree.vistr_mut().dfs_preorder_iter());
     assert_length(tree.vistr().dfs_preorder_iter());
@@ -32,7 +33,7 @@ fn test() {
 
     recc(tree.vistr_mut());
     //recursively check that the length is correct at each node.
-    fn recc(a: VistrMut<Node<BBox<isize, &mut usize>>>) {
+    fn recc(a: VistrMutPin<Node<BBox<isize, &mut usize>>>) {
         let (_nn, rest) = a.next();
         match rest {
             Some([mut left, mut right]) => {
